@@ -14,10 +14,10 @@ Norm <- function(parMean, parCovar, parRange = NULL, num) {
   if (nc != length(parMean))
     stop ("cannot generate Normal distribution: parCovar and parMean not compatible")
 
-  if (nc ==1)
-    return (matrix(data=rnorm(n = num, mean = parMean, sd = sqrt(parCovar)), ncol = nc))
-  R   <- chol(parCovar)   # Cholesky decomposition
-  Z   <- matrix(data = rnorm(num*nc),ncol = nc)
+  if (nc == 1)
+    return(matrix(rnorm(n = num, mean = parMean, sd = sqrt(parCovar)), ncol = nc))
+  R <- chol(parCovar)   # Cholesky decomposition
+  Z <- matrix(data = rnorm(num*nc), ncol = nc)
 
   parset <- Z %*% R
   for (i in 1:nc) parset[,i] <- parset[,i] + parMean[i]
